@@ -15,8 +15,6 @@ import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_comprehend.paginator import (
     ListDocumentClassificationJobsPaginator,
@@ -99,29 +97,37 @@ else:
 __all__ = ("ComprehendClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    BatchSizeLimitExceededException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    ConcurrentModificationException: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    InvalidFilterException: Type[Boto3ClientError]
-    InvalidRequestException: Type[Boto3ClientError]
-    JobNotFoundException: Type[Boto3ClientError]
-    KmsKeyValidationException: Type[Boto3ClientError]
-    ResourceInUseException: Type[Boto3ClientError]
-    ResourceLimitExceededException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ResourceUnavailableException: Type[Boto3ClientError]
-    TextSizeLimitExceededException: Type[Boto3ClientError]
-    TooManyRequestsException: Type[Boto3ClientError]
-    TooManyTagKeysException: Type[Boto3ClientError]
-    TooManyTagsException: Type[Boto3ClientError]
-    UnsupportedLanguageException: Type[Boto3ClientError]
+    BatchSizeLimitExceededException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    ConcurrentModificationException: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    InvalidFilterException: Type[BotocoreClientError]
+    InvalidRequestException: Type[BotocoreClientError]
+    JobNotFoundException: Type[BotocoreClientError]
+    KmsKeyValidationException: Type[BotocoreClientError]
+    ResourceInUseException: Type[BotocoreClientError]
+    ResourceLimitExceededException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ResourceUnavailableException: Type[BotocoreClientError]
+    TextSizeLimitExceededException: Type[BotocoreClientError]
+    TooManyRequestsException: Type[BotocoreClientError]
+    TooManyTagKeysException: Type[BotocoreClientError]
+    TooManyTagsException: Type[BotocoreClientError]
+    UnsupportedLanguageException: Type[BotocoreClientError]
 
 
 class ComprehendClient:
     """
-    [Comprehend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client)
+    [Comprehend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client)
     """
 
     meta: ClientMeta
@@ -131,7 +137,7 @@ class ComprehendClient:
         self, TextList: List[str]
     ) -> BatchDetectDominantLanguageResponseTypeDef:
         """
-        [Client.batch_detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.batch_detect_dominant_language)
+        [Client.batch_detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.batch_detect_dominant_language)
         """
 
     def batch_detect_entities(
@@ -142,7 +148,7 @@ class ComprehendClient:
         ],
     ) -> BatchDetectEntitiesResponseTypeDef:
         """
-        [Client.batch_detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.batch_detect_entities)
+        [Client.batch_detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.batch_detect_entities)
         """
 
     def batch_detect_key_phrases(
@@ -153,7 +159,7 @@ class ComprehendClient:
         ],
     ) -> BatchDetectKeyPhrasesResponseTypeDef:
         """
-        [Client.batch_detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.batch_detect_key_phrases)
+        [Client.batch_detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.batch_detect_key_phrases)
         """
 
     def batch_detect_sentiment(
@@ -164,24 +170,24 @@ class ComprehendClient:
         ],
     ) -> BatchDetectSentimentResponseTypeDef:
         """
-        [Client.batch_detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.batch_detect_sentiment)
+        [Client.batch_detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.batch_detect_sentiment)
         """
 
     def batch_detect_syntax(
         self, TextList: List[str], LanguageCode: Literal["en", "es", "fr", "de", "it", "pt"]
     ) -> BatchDetectSyntaxResponseTypeDef:
         """
-        [Client.batch_detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.batch_detect_syntax)
+        [Client.batch_detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.batch_detect_syntax)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.can_paginate)
         """
 
     def classify_document(self, Text: str, EndpointArn: str) -> ClassifyDocumentResponseTypeDef:
         """
-        [Client.classify_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.classify_document)
+        [Client.classify_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.classify_document)
         """
 
     def create_document_classifier(
@@ -200,7 +206,7 @@ class ComprehendClient:
         Mode: Literal["MULTI_CLASS", "MULTI_LABEL"] = None,
     ) -> CreateDocumentClassifierResponseTypeDef:
         """
-        [Client.create_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.create_document_classifier)
+        [Client.create_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.create_document_classifier)
         """
 
     def create_endpoint(
@@ -212,7 +218,7 @@ class ComprehendClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateEndpointResponseTypeDef:
         """
-        [Client.create_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
+        [Client.create_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
         """
 
     def create_entity_recognizer(
@@ -229,88 +235,88 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> CreateEntityRecognizerResponseTypeDef:
         """
-        [Client.create_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.create_entity_recognizer)
+        [Client.create_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.create_entity_recognizer)
         """
 
     def delete_document_classifier(self, DocumentClassifierArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.delete_document_classifier)
+        [Client.delete_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.delete_document_classifier)
         """
 
     def delete_endpoint(self, EndpointArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.delete_endpoint)
+        [Client.delete_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.delete_endpoint)
         """
 
     def delete_entity_recognizer(self, EntityRecognizerArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.delete_entity_recognizer)
+        [Client.delete_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.delete_entity_recognizer)
         """
 
     def describe_document_classification_job(
         self, JobId: str
     ) -> DescribeDocumentClassificationJobResponseTypeDef:
         """
-        [Client.describe_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_document_classification_job)
+        [Client.describe_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_document_classification_job)
         """
 
     def describe_document_classifier(
         self, DocumentClassifierArn: str
     ) -> DescribeDocumentClassifierResponseTypeDef:
         """
-        [Client.describe_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_document_classifier)
+        [Client.describe_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_document_classifier)
         """
 
     def describe_dominant_language_detection_job(
         self, JobId: str
     ) -> DescribeDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.describe_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_dominant_language_detection_job)
+        [Client.describe_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_dominant_language_detection_job)
         """
 
     def describe_endpoint(self, EndpointArn: str) -> DescribeEndpointResponseTypeDef:
         """
-        [Client.describe_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_endpoint)
+        [Client.describe_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_endpoint)
         """
 
     def describe_entities_detection_job(
         self, JobId: str
     ) -> DescribeEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.describe_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_entities_detection_job)
+        [Client.describe_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_entities_detection_job)
         """
 
     def describe_entity_recognizer(
         self, EntityRecognizerArn: str
     ) -> DescribeEntityRecognizerResponseTypeDef:
         """
-        [Client.describe_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_entity_recognizer)
+        [Client.describe_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_entity_recognizer)
         """
 
     def describe_key_phrases_detection_job(
         self, JobId: str
     ) -> DescribeKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.describe_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_key_phrases_detection_job)
+        [Client.describe_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_key_phrases_detection_job)
         """
 
     def describe_sentiment_detection_job(
         self, JobId: str
     ) -> DescribeSentimentDetectionJobResponseTypeDef:
         """
-        [Client.describe_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_sentiment_detection_job)
+        [Client.describe_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_sentiment_detection_job)
         """
 
     def describe_topics_detection_job(
         self, JobId: str
     ) -> DescribeTopicsDetectionJobResponseTypeDef:
         """
-        [Client.describe_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.describe_topics_detection_job)
+        [Client.describe_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.describe_topics_detection_job)
         """
 
     def detect_dominant_language(self, Text: str) -> DetectDominantLanguageResponseTypeDef:
         """
-        [Client.detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.detect_dominant_language)
+        [Client.detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.detect_dominant_language)
         """
 
     def detect_entities(
@@ -322,7 +328,7 @@ class ComprehendClient:
         EndpointArn: str = None,
     ) -> DetectEntitiesResponseTypeDef:
         """
-        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.detect_entities)
+        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.detect_entities)
         """
 
     def detect_key_phrases(
@@ -333,7 +339,7 @@ class ComprehendClient:
         ],
     ) -> DetectKeyPhrasesResponseTypeDef:
         """
-        [Client.detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.detect_key_phrases)
+        [Client.detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.detect_key_phrases)
         """
 
     def detect_sentiment(
@@ -344,14 +350,14 @@ class ComprehendClient:
         ],
     ) -> DetectSentimentResponseTypeDef:
         """
-        [Client.detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.detect_sentiment)
+        [Client.detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.detect_sentiment)
         """
 
     def detect_syntax(
         self, Text: str, LanguageCode: Literal["en", "es", "fr", "de", "it", "pt"]
     ) -> DetectSyntaxResponseTypeDef:
         """
-        [Client.detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.detect_syntax)
+        [Client.detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.detect_syntax)
         """
 
     def generate_presigned_url(
@@ -362,7 +368,7 @@ class ComprehendClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.generate_presigned_url)
         """
 
     def list_document_classification_jobs(
@@ -372,7 +378,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDocumentClassificationJobsResponseTypeDef:
         """
-        [Client.list_document_classification_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_document_classification_jobs)
+        [Client.list_document_classification_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_document_classification_jobs)
         """
 
     def list_document_classifiers(
@@ -382,7 +388,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDocumentClassifiersResponseTypeDef:
         """
-        [Client.list_document_classifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_document_classifiers)
+        [Client.list_document_classifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_document_classifiers)
         """
 
     def list_dominant_language_detection_jobs(
@@ -392,14 +398,14 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDominantLanguageDetectionJobsResponseTypeDef:
         """
-        [Client.list_dominant_language_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_dominant_language_detection_jobs)
+        [Client.list_dominant_language_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_dominant_language_detection_jobs)
         """
 
     def list_endpoints(
         self, Filter: EndpointFilterTypeDef = None, NextToken: str = None, MaxResults: int = None
     ) -> ListEndpointsResponseTypeDef:
         """
-        [Client.list_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_endpoints)
+        [Client.list_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_endpoints)
         """
 
     def list_entities_detection_jobs(
@@ -409,7 +415,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListEntitiesDetectionJobsResponseTypeDef:
         """
-        [Client.list_entities_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_entities_detection_jobs)
+        [Client.list_entities_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_entities_detection_jobs)
         """
 
     def list_entity_recognizers(
@@ -419,7 +425,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListEntityRecognizersResponseTypeDef:
         """
-        [Client.list_entity_recognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_entity_recognizers)
+        [Client.list_entity_recognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_entity_recognizers)
         """
 
     def list_key_phrases_detection_jobs(
@@ -429,7 +435,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListKeyPhrasesDetectionJobsResponseTypeDef:
         """
-        [Client.list_key_phrases_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_key_phrases_detection_jobs)
+        [Client.list_key_phrases_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_key_phrases_detection_jobs)
         """
 
     def list_sentiment_detection_jobs(
@@ -439,12 +445,12 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListSentimentDetectionJobsResponseTypeDef:
         """
-        [Client.list_sentiment_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_sentiment_detection_jobs)
+        [Client.list_sentiment_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_sentiment_detection_jobs)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_tags_for_resource)
         """
 
     def list_topics_detection_jobs(
@@ -454,7 +460,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListTopicsDetectionJobsResponseTypeDef:
         """
-        [Client.list_topics_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.list_topics_detection_jobs)
+        [Client.list_topics_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.list_topics_detection_jobs)
         """
 
     def start_document_classification_job(
@@ -469,7 +475,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDocumentClassificationJobResponseTypeDef:
         """
-        [Client.start_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_document_classification_job)
+        [Client.start_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_document_classification_job)
         """
 
     def start_dominant_language_detection_job(
@@ -483,7 +489,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.start_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_dominant_language_detection_job)
+        [Client.start_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_dominant_language_detection_job)
         """
 
     def start_entities_detection_job(
@@ -501,7 +507,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.start_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_entities_detection_job)
+        [Client.start_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_entities_detection_job)
         """
 
     def start_key_phrases_detection_job(
@@ -518,7 +524,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.start_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_key_phrases_detection_job)
+        [Client.start_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_key_phrases_detection_job)
         """
 
     def start_sentiment_detection_job(
@@ -535,7 +541,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartSentimentDetectionJobResponseTypeDef:
         """
-        [Client.start_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_sentiment_detection_job)
+        [Client.start_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_sentiment_detection_job)
         """
 
     def start_topics_detection_job(
@@ -550,56 +556,56 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartTopicsDetectionJobResponseTypeDef:
         """
-        [Client.start_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.start_topics_detection_job)
+        [Client.start_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.start_topics_detection_job)
         """
 
     def stop_dominant_language_detection_job(
         self, JobId: str
     ) -> StopDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.stop_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_dominant_language_detection_job)
+        [Client.stop_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_dominant_language_detection_job)
         """
 
     def stop_entities_detection_job(self, JobId: str) -> StopEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.stop_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_entities_detection_job)
+        [Client.stop_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_entities_detection_job)
         """
 
     def stop_key_phrases_detection_job(
         self, JobId: str
     ) -> StopKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.stop_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_key_phrases_detection_job)
+        [Client.stop_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_key_phrases_detection_job)
         """
 
     def stop_sentiment_detection_job(self, JobId: str) -> StopSentimentDetectionJobResponseTypeDef:
         """
-        [Client.stop_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_sentiment_detection_job)
+        [Client.stop_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_sentiment_detection_job)
         """
 
     def stop_training_document_classifier(self, DocumentClassifierArn: str) -> Dict[str, Any]:
         """
-        [Client.stop_training_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_training_document_classifier)
+        [Client.stop_training_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_training_document_classifier)
         """
 
     def stop_training_entity_recognizer(self, EntityRecognizerArn: str) -> Dict[str, Any]:
         """
-        [Client.stop_training_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.stop_training_entity_recognizer)
+        [Client.stop_training_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.stop_training_entity_recognizer)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.untag_resource)
         """
 
     def update_endpoint(self, EndpointArn: str, DesiredInferenceUnits: int) -> Dict[str, Any]:
         """
-        [Client.update_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Client.update_endpoint)
+        [Client.update_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Client.update_endpoint)
         """
 
     @overload
@@ -607,7 +613,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_document_classification_jobs"]
     ) -> ListDocumentClassificationJobsPaginator:
         """
-        [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
+        [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
         """
 
     @overload
@@ -615,7 +621,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_document_classifiers"]
     ) -> ListDocumentClassifiersPaginator:
         """
-        [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
+        [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
         """
 
     @overload
@@ -623,7 +629,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_dominant_language_detection_jobs"]
     ) -> ListDominantLanguageDetectionJobsPaginator:
         """
-        [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
+        [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
         """
 
     @overload
@@ -631,7 +637,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_entities_detection_jobs"]
     ) -> ListEntitiesDetectionJobsPaginator:
         """
-        [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
+        [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
         """
 
     @overload
@@ -639,7 +645,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_entity_recognizers"]
     ) -> ListEntityRecognizersPaginator:
         """
-        [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
+        [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
         """
 
     @overload
@@ -647,7 +653,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_key_phrases_detection_jobs"]
     ) -> ListKeyPhrasesDetectionJobsPaginator:
         """
-        [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
+        [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
         """
 
     @overload
@@ -655,7 +661,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_sentiment_detection_jobs"]
     ) -> ListSentimentDetectionJobsPaginator:
         """
-        [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
+        [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
         """
 
     @overload
@@ -663,8 +669,5 @@ class ComprehendClient:
         self, operation_name: Literal["list_topics_detection_jobs"]
     ) -> ListTopicsDetectionJobsPaginator:
         """
-        [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
+        [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
